@@ -31,7 +31,9 @@ class Cli:
         self._file_handler = FileHandler()
         self.args = self._args_parser.parse_args()
         self.lexicanum = None
+        self.use_lexicanum = False
         self.recipe = None
+        self.output_path = None
 
 
     def _init_argparser(self):
@@ -75,7 +77,7 @@ class Cli:
         parser.add_argument(
             "--output-dir","-o",
             help="Path to a directory that will contain the generated lookml files",
-            default=self.DEFAULT_LOOKML_OUTPUT_DIR,
+            default=None,
             type=str,
         )
         return parser
@@ -117,12 +119,16 @@ class Cli:
         if folder is None:
             folder = args.config
         if not os.path.exists(folder):
-            raise FileNotFoundError(f"Folder {folder} does not exist")
+            raise FileNotFoundError(f"Folder {folder} where loader_config.yml is expected does not exist")
 
         logging.info(f"Loading Config from {folder}/loader_config.yml")
         data = self._file_handler.read(f"{folder}/loader_config.yml", file_type="yaml")
         self.config = Config(**data['config'])
 
+        self.output_path = args.output_dir or self.config.loader.output_path or self.DEFAULT_LOOKML_OUTPUT_DIR
+        self.use_lexicanum = args.lex or self.config.loader.lexicanum or False
+
+
     def _load_tables(self):
         """Load the schemas from the database"""
         process_list = []
@@ -178,18 +184,29 @@ class Cli:
             lex_fields = {}
         logging.info("Lexicanum is enabled. Collecting lexical fields from schemas...")
 
+        def recurse_fields(fields, lex_fields):
+            """Recursively collect fields from nested structures"""
+            if isinstance(fields, list):  # Ensure 'fields' is a list
+                for field in fields:
+                    if field.name not in lex_fields:
+                        lex_fields[field.name] = {'label': None}
+                    if field.fields:
+                        recurse_fields(field.fields, lex_fields)
+
         for m in self.schemas:
             schema = m.get("schema")
             for field in schema.fields:
-                if field.name in lex_fields.keys():
-                    continue
-                else:
-                    lex_fields[field.name] = {'label': None}
+                if field.name not in lex_fields:
+                    lex_fields[field.name] = {'label': None}  # Or extract label if needed
+
+                # Recurse if the field has nested fields
+                if hasattr(field, 'fields') and field.fields:
+                    recurse_fields(field.fields, lex_fields)
 
         logging.debug("Lexical fields collected from mixtures, writing to lexicanum.yml")
         # Write to a YAML file
         with open('lexicanum.yml', 'w') as file:
-            yaml.dump(lex_fields, file, sort_keys=True)
+            yaml.dump(lex_fields, file, sort_keys=True, allow_unicode=True)
 
         self.lexicanum = Lex(lex_fields)
 
@@ -236,7 +253,7 @@ class Cli:
         # retrieve the schemas of the tables
         asyncio.run(self.get_schemas())
 
-        if self.args.lex:
+        if self.use_lexicanum:
             self._load_lexicanum()
 
         self._initialize_mixer()
@@ -259,7 +276,7 @@ class Cli:
                 config=config,
             )
             self._write_lookml_file(
-                output_dir=f'{self.args.output_dir}/{table_group}',
+                output_dir=f'{self.output_path}/{table_group}',
                 file_path=f'{config.prefix_files}{mixture.name}{config.suffix_files}.view.lkml',
                 contents=convert_to_lkml(views, explore),
             )
