@@ -36,6 +36,7 @@ class LookerViewElement(BaseModel):
     tags: Optional[List[str]] = None
 
     value_format_name: Optional[str] = Field(default=None)
+    value_format: Optional[str] = None
     group_label: Optional[str] = None
 
     @field_validator("value_format_name", mode="before")
@@ -77,6 +78,7 @@ class LookerMeasure(LookerViewElement):
     required_access_grants: Optional[List[str]] = Field(default=None)
     filters: Optional[List[LookerMeasureFilter]] = None
     sql: Optional[str] = None  # SQL expression for the measure
+    alias: Optional[List[str]] = None
 
     @field_validator("hidden", "approximate", mode="after")
     @classmethod
@@ -153,6 +155,7 @@ class LookerDimension(LookerViewElement):
     required_access_grants: Optional[List[str]] = Field(default=None)
     html: Optional[str] = Field(default=None)
     sql: Optional[str] = None
+    alias: Optional[List[str]] = None
     # fields: Optional[List['LookerDimension']] = None
 
 
@@ -217,8 +220,12 @@ class ValidatedLookerDimensionGroup(LookerDimension):
         if value is not None:
             value = value.replace(".", "__")
         # Remove the last part after the underscore if it exists
+        # this is not a good idea. Looker conditionally removes the last part _ given specific criteria.
+        # for example: event_at becomes event. but happened_at does not become happened.s 
+        # That seems like an oversight to me, and not something worth trying to replicate.
         if "_" in value:
-            value = value.rsplit("_", 1)[0]
+            if value.rsplit("_", 1)[-1] in ("at", "date"):
+                value = value.rsplit("_", 1)[0]
         return value
     
 class ValidatedLookerMeasure(LookerMeasure):
